@@ -1,11 +1,10 @@
-use 5.008;    # 08 -> [utf8], 06 -> [pragmas, our]
-use utf8;
+use 5.006;    # 06 -> [pragmas, our]
 use strict;
 use warnings;
 
 package Dist::Zilla::Tempdir::Item::State;
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001003';
 
 # ABSTRACT: Intermediate state for a file
 
@@ -185,7 +184,7 @@ Dist::Zilla::Tempdir::Item::State - Intermediate state for a file
 
 =head1 VERSION
 
-version 1.001001
+version 1.001003
 
 =head1 ATTRIBUTES
 
@@ -234,7 +233,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
